<?php

/*
Plugin Name: Calculadora Fitness dr
Description: Procure na barra lateral do WordPress pelo item Calc Fitness, lá você vai encontrar as calculadoras e as instruções de uso. A utilização deste plugin é de total responsabilidade do usuário. O desenvolvedor não se responsabiliza por qualquer dano, perda de dados ou problemas que possam ocorrer em decorrência do uso ou instalação deste plugin. Recomenda-se realizar backups regulares antes de qualquer instalação e atualização. Ao utilizar este plugin, o usuário concorda com esses termos.
Version: 1.5
Author: Prof. Durval de Deus
Author URI: https://ambr.com.br/sobre-os-autores/
*/

// Prevenir acesso direto ao arquivo
if (!defined('ABSPATH')) {
    exit;
}

function fcp_add_admin_menu() {
    add_menu_page(
        'Calc Fitness', 
        'Calc Fitness', 
        'manage_options',   
        'fcp_admin_page',   
        'fcp_render_admin_page', 
        'dashicons-admin-customizer', 
        110
    );
}
add_action( 'admin_menu', 'fcp_add_admin_menu' );


function fcp_render_admin_page() {
    ?>
    <div class="container" style="max-width: 800px; margin: 0 auto; padding: 20px; background-color: #fff; box-shadow: 0px 4px 8px rgba(0, 0, 0, 0.1); border-radius: 10px;">
        <h1>Shortcodes das Calculadoras</h1>
		<h2>INSTRUÇÕES</h2>
        <h3>Ao clicar no botão ao lado do nome da calculadora você irá copiar o shortcode da calculadora escolhida.</h3>
        <h3>Cole este shortcode em qualquer parte da área de edição do seu post para que ali seja inserida a calculadora desejada.</h3>
        <p><strong style="color: red;">ATENÇÃO</strong> - Não use mais que uma calculadora por postagem</p>
		<p>Este plugin é registrado a cópia, distribuição ou modificação do código é proibida.. </p>
        <hr style="border: 1px solid black; width: 50%; margin-bottom: 10px;">

        <ul style="list-style-type: none; padding: 0;">
            <?php
            $calculadoras = array(
                'Calculadora de VO2 Máx' => array(
                    'shortcode' => '[calc_vo2_max_dr]',
                    'descricao' => 'Calcula o volume máximo de oxigênio que seu corpo pode utilizar durante o exercício.'
                ),
                'Calculadora de Reserva de VO2' => array(
                    'shortcode' => '[calc_reserva_vo2_dr]',
                    'descricao' => 'Determina a reserva de oxigênio do corpo para medir a intensidade do exercício.'
                ),
                'Calculadora de Macronutrientes' => array(
                    'shortcode' => '[calc_macronutrientes_dr]',
                    'descricao' => 'Calcula a quantidade ideal de macronutrientes (proteínas, carboidratos e gorduras) para sua dieta.'
                ),
                'Calculadora de volume de treino' => array(
                    'shortcode' => '[calc_volume_treino_dr]',
                    'descricao' => 'Avalia o volume de treino baseado na quantidade de repetições e séries realizadas.'
                ),
                'Calculadora de Força Máxima (1RM)' => array(
                    'shortcode' => '[calc_forca_maxima_dr]',
                    'descricao' => 'Estima a carga máxima que você consegue levantar em uma única repetição.'
                ),
                'Calculadora de Consumo Diário de Água' => array(
                    'shortcode' => '[calc_consumo_agua_dr]',
                    'descricao' => 'Calcula a quantidade ideal de água que você deve consumir diariamente com base no seu peso.'
                ),
                'Calculadora de Frequência Cardíaca Máxima' => array(
                    'shortcode' => '[calc_freq_cardiaca_maxima_dr]',
                    'descricao' => 'Determina sua frequência cardíaca máxima com base na idade para ajudar a monitorar a intensidade do exercício.'
                ),
                'Calculadora de Índice de Massa Corporal (IMC)' => array(
                    'shortcode' => '[calc_imc_dr]',
                    'descricao' => 'Calcula o seu Índice de Massa Corporal (IMC) para classificar seu peso em relação à altura.'
                ),
                'Calculadora de Percentual de Gordura Corporal' => array(
                    'shortcode' => '[calc_percentual_gordura_dr]',
                    'descricao' => 'Estima o percentual de gordura corporal baseado em medições corporais.'
                ),
                'Calculadora de Metas de Perda ou Ganho de Peso' => array(
                    'shortcode' => '[calc_metas_peso_dr]',
                    'descricao' => 'Ajuda a definir metas para perda ou ganho de peso com base no consumo calórico.'
                ),
            );

            foreach ( $calculadoras as $nome => $dados ) {
                echo '<li style="margin-bottom: 20px; background-color: #f9f9f9; padding: 20px; border: 1px solid #ddd; border-radius: 5px;">';
                echo '<strong>' . esc_html( $nome ) . '</strong>';
                echo ' <button class="button fcp-copy-btn" data-clipboard-text="' . esc_attr( $dados['shortcode'] ) . '" style="margin-left: 10px;">Copiar shortcode</button>';
                echo '<p>' . esc_html( $dados['descricao'] ) . '</p>';
                //echo '<hr style="border: 1px solid black; width: 100%; margin-bottom: 20px;">';  // Adiciona a linha divisória
                echo '</li>';
            }
            ?>
        </ul>
    </div>
    <?php
}

function fcp_enqueue_admin_scripts($hook) {
    if ( 'toplevel_page_fcp_admin_page' !== $hook ) {
        return;
    }
    wp_enqueue_script( 'clipboard-js', 'https://cdnjs.cloudflare.com/ajax/libs/clipboard.js/2.0.6/clipboard.min.js', array(), '2.0.6', true );
    wp_add_inline_script( 'clipboard-js', "
        document.addEventListener('DOMContentLoaded', function() {
            var clipboard = new ClipboardJS('.fcp-copy-btn');
            clipboard.on('success', function(e) {
                alert('Shortcode copiado para o clipboard: ' + e.text);
                e.clearSelection();
            });
            clipboard.on('error', function(e) {
                alert('Falha ao copiar!');
            });
        });
    ");
}
add_action( 'admin_enqueue_scripts', 'fcp_enqueue_admin_scripts' );

function calculadora_fitness_dr_enqueue_scripts() {
    wp_enqueue_style('calculadora-fitness-dr-style', plugins_url('/css/style.css', __FILE__));
    wp_enqueue_script('calculadora-fitness-dr-script', plugins_url('/js/scripts.js', __FILE__), array('jquery'), null, true);
}
add_action('wp_enqueue_scripts', 'calculadora_fitness_dr_enqueue_scripts');

function calculator_template_start($title) {
    ob_start();
    ?>
    <div class="calculator-wrapper" style="display: flex; justify-content: center; align-items: center; min-height: 50vh; margin: 20px 0;">
        <div class="calculator-container" style="max-width: 600px; width: 100%; text-align: center; padding: 20px; border: 1px solid #ddd; border-radius: 10px; box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1); background-color: #f9f9f9;">
            <h2><?php echo $title; ?></h2>
    <?php
}

function calculator_template_end() {
    ?>
        </div>
    </div>
    <?php
    return ob_get_clean();
}

function calculator_volume_treino() {
    echo calculator_template_start('Calcule o Volume Ideal de Treino Ajustado pela Idade');
    ?>
    <form id="volumeTreinoForm" style="font-family: Arial, sans-serif; max-width: 400px; margin: auto;">
        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required min="1" max="100" aria-label="Idade em anos" 
               style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 25">

        <label for="sets">Número de Séries:</label>
        <input type="number" id="sets" name="sets" required min="1" aria-label="Número de séries" 
               style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 4">

        <label for="reps">Número de Repetições por Série:</label>
        <input type="number" id="reps" name="reps" required min="1" aria-label="Número de repetições por série" 
               style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 12">

        <label for="carga">Carga Utilizada (kg):</label>
        <input type="number" id="carga" name="carga" required min="1" aria-label="Carga utilizada em quilogramas" 
               style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 50">

        <button type="submit" style="width: 100%; background-color: #28A745; color: white; padding: 10px; border: none; cursor: pointer;">
            Calcular Volume Ideal
        </button>
    </form>

    <div id="resultado" style="margin-top: 20px; text-align: center; font-family: Arial, sans-serif;"></div>

    <script>
    document.getElementById("volumeTreinoForm").addEventListener("submit", function(event) {
        event.preventDefault();
        
        // Capturando valores do formulário
        var idade = parseFloat(document.getElementById("idade").value);
        var sets = parseFloat(document.getElementById("sets").value);
        var reps = parseFloat(document.getElementById("reps").value);
        var carga = parseFloat(document.getElementById("carga").value);

        // Validações adicionais
        if (isNaN(idade) || isNaN(sets) || isNaN(reps) || isNaN(carga) || 
            idade <= 0 || sets <= 0 || reps <= 0 || carga <= 0) {
            document.getElementById("resultado").innerHTML = "<h3 style='color: red;'>Por favor, preencha todos os campos corretamente com valores válidos.</h3>";
            return;
        }

        if (idade > 100) {
            document.getElementById("resultado").innerHTML = "<h3 style='color: red;'>Por favor, insira uma idade válida (máximo: 100 anos).</h3>";
            return;
        }

        // Cálculo do volume básico e ajustado
        var volumeBasico = sets * reps * carga;
        var fatorIdade = Math.max((100 - idade) / 100, 0.5); // Ajuste para garantir fator mínimo de 0.5
        var volumeIdeal = volumeBasico * fatorIdade;

        // Exibição do resultado
        document.getElementById("resultado").innerHTML = `
            <div style="border: 2px solid #28A745; padding: 15px; border-radius: 5px; background-color: #f9f9f9;">
                <h3 style="color: #28A745;">Resultados do Cálculo de Volume de Treino</h3>
                <p><strong>Volume Básico de Treino:</strong> ${volumeBasico.toFixed(2)} kg</p>
                <p><strong>Fator de Ajuste pela Idade:</strong> ${fatorIdade.toFixed(2)}</p>
                <p><strong>Volume Ideal de Treino:</strong> ${volumeIdeal.toFixed(2)} kg</p>
                <p>Este valor ajusta o volume de treino considerando a idade para um desempenho mais eficiente.</p>
            </div>`;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_volume_treino_dr', 'calculator_volume_treino');


function calculator_forca_maxima() {
    echo calculator_template_start('Calcule sua Força Máxima (1RM)');
    ?>
    <form id="forcaMaximaForm" style="font-family: Arial, sans-serif; max-width: 400px; margin: auto;">
        <label for="carga">Carga levantada (kg):</label>
        <input type="number" id="carga" name="carga" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 100">

        <label for="reps">Número de repetições:</label>
        <input type="number" id="reps" name="reps" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 10">

        <button type="submit" style="width: 100%; background-color: #17A2B8; color: white; padding: 10px; border: none; cursor: pointer;">Calcular Força Máxima</button>
    </form>

    <div id="resultado" style="margin-top: 20px; text-align: center; font-family: Arial, sans-serif;"></div>

    <script>
    document.getElementById("forcaMaximaForm").addEventListener("submit", function(event) {
        event.preventDefault();
        
        var carga = parseFloat(document.getElementById("carga").value);
        var reps = parseFloat(document.getElementById("reps").value);

        if (isNaN(carga) || isNaN(reps) || carga <= 0 || reps <= 0) {
            document.getElementById("resultado").innerHTML = "<h3 style='color: red;'>Por favor, insira valores válidos para carga e repetições.</h3>";
            return;
        }

        var forcaMaxima = carga * (1 + reps / 30);

        document.getElementById("resultado").innerHTML = `
            <div style="border: 2px solid #17A2B8; padding: 15px; border-radius: 5px; background-color: #f9f9f9;">
                <h3 style="color: #17A2B8;">Resultado da Estimativa de Força Máxima</h3>
                <p><strong>Força Máxima Estimada (1RM):</strong> ${forcaMaxima.toFixed(2)} kg</p>
                <p>Este valor representa sua força máxima estimada com base na carga e nas repetições fornecidas.</p>
            </div>`;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_forca_maxima_dr', 'calculator_forca_maxima');


function calculator_vo2r() {
    echo calculator_template_start('Calculadora de Reserva de VO2 (VO2R)');
    ?>
    <form id="vo2rForm" style="font-family: Arial, sans-serif; max-width: 400px; margin: auto;">
        <label for="vo2max">VO2 Máximo (ml/kg/min):</label>
        <input type="number" id="vo2max" name="vo2max" step="0.1" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 45.0">

        <label for="vo2repouso">VO2 de Repouso (ml/kg/min):</label>
        <input type="number" id="vo2repouso" name="vo2repouso" value="3.5" step="0.1" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="3.5">

        <label for="intensidade">Intensidade do Exercício (%):</label>
        <input type="number" id="intensidade" name="intensidade" step="0.1" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 60 (% da capacidade máxima)">

        <label for="idade">Idade (opcional, anos):</label>
        <input type="number" id="idade" name="idade" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 30">

        <button type="submit" style="width: 100%; background-color: #007BFF; color: white; padding: 10px; border: none; cursor: pointer;">Calcular VO2R</button>
    </form>

    <div id="resultado" style="margin-top: 20px; text-align: center; font-family: Arial, sans-serif;"></div>

    <script>
    document.getElementById("vo2rForm").addEventListener("submit", function(event) {
        event.preventDefault();
        
        var vo2max = parseFloat(document.getElementById("vo2max").value);
        var vo2repouso = parseFloat(document.getElementById("vo2repouso").value);
        var intensidade = parseFloat(document.getElementById("intensidade").value);

        // Validação dos campos obrigatórios
        if (isNaN(vo2max) || isNaN(vo2repouso) || isNaN(intensidade) || vo2max <= 0 || intensidade <= 0 || intensidade > 100) {
            document.getElementById("resultado").innerHTML = "<h3 style='color: red;'>Por favor, insira valores válidos para todos os campos obrigatórios.</h3>";
            return;
        }

        // Validação específica para VO2 Máximo e VO2 de repouso
        if (vo2max <= vo2repouso) {
            document.getElementById("resultado").innerHTML = "<h3 style='color: red;'>O VO2 máximo deve ser maior que o VO2 de repouso.</h3>";
            return;
        }

        var vo2r = vo2max - vo2repouso;
        var vo2intensidade = vo2repouso + (vo2r * (intensidade / 100));

        // Classificação da intensidade
        var categoria;
        if (intensidade < 40) {
            categoria = "Leve";
        } else if (intensidade < 70) {
            categoria = "Moderado";
        } else {
            categoria = "Vigoroso";
        }

        // Resultado formatado
        document.getElementById("resultado").innerHTML = `
            <div style="border: 2px solid #007BFF; padding: 15px; border-radius: 5px; background-color: #f9f9f9;">
                <h3 style="color: #007BFF;">Resultados da Reserva de VO2</h3>
                <p><strong>VO2 de Exercício (VO2R):</strong> ${vo2intensidade.toFixed(2)} ml/kg/min</p>
                <p><strong>Categoria de Intensidade:</strong> ${categoria}</p>
                <p>O VO2R ajuda a planejar treinos de acordo com a capacidade cardiovascular.</p>
            </div>`;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_reserva_vo2_dr', 'calculator_vo2r');

function calculator_metas_peso() {
    echo calculator_template_start('Calcule suas Metas de Perda ou Ganho de Peso');
    ?>
    <form id="metasPesoForm" style="font-family: Arial, sans-serif; max-width: 400px; margin: auto;">
        <label for="pesoAtual">Peso Atual (kg):</label>
        <input type="number" id="pesoAtual" name="pesoAtual" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 75.0" min="30" max="300" step="0.1" aria-label="Insira seu peso atual">

        <label for="pesoDesejado">Peso Desejado (kg):</label>
        <input type="number" id="pesoDesejado" name="pesoDesejado" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 70.0" min="30" max="300" step="0.1" aria-label="Insira seu peso desejado">

        <label for="dias">Tempo para a meta (dias):</label>
        <input type="number" id="dias" name="dias" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 30" min="1" max="365" aria-label="Insira o tempo em dias">

        <button type="submit" style="width: 100%; background-color: #28A745; color: white; padding: 10px; border: none; cursor: pointer;">Calcular Meta de Peso</button>
    </form>
    
    <div id="resultado" style="margin-top: 20px; text-align: center; font-family: Arial, sans-serif;"></div>

    <script>
    document.getElementById("metasPesoForm").addEventListener("submit", function(event) {
        event.preventDefault();
        
        var pesoAtual = parseFloat(document.getElementById("pesoAtual").value);
        var pesoDesejado = parseFloat(document.getElementById("pesoDesejado").value);
        var dias = parseInt(document.getElementById("dias").value);

        if (isNaN(pesoAtual) || isNaN(pesoDesejado) || isNaN(dias) || pesoAtual <= 0 || pesoDesejado <= 0 || dias <= 0) {
            document.getElementById("resultado").innerHTML = "<h3 style='color: red;'>Por favor, insira valores válidos para todos os campos.</h3>";
            return;
        }

        var diferencaPeso = pesoDesejado - pesoAtual;
        var metaPorDia = diferencaPeso / dias;

        if (Math.abs(metaPorDia) > 0.5) {
            document.getElementById("resultado").innerHTML = `
                <div style="border: 2px solid #FF0000; padding: 15px; border-radius: 5px; background-color: #fff0f0;">
                    <h3 style="color: #FF0000;">Meta Extremamente Desafiadora</h3>
                    <p>Você precisará perder ou ganhar mais de <strong>0.5 kg</strong> por dia, o que pode ser perigoso. Reavalie sua meta ou prazo!</p>
                </div>`;
            return;
        }

        var tipoMeta = diferencaPeso < 0 ? "perder" : "ganhar";

        document.getElementById("resultado").innerHTML = `
            <div style="border: 2px solid #28A745; padding: 15px; border-radius: 5px; background-color: #f9f9f9;">
                <h3 style="color: #28A745;">Sua Meta de Peso</h3>
                <p><strong>Peso Atual:</strong> ${pesoAtual.toFixed(1)} kg</p>
                <p><strong>Peso Desejado:</strong> ${pesoDesejado.toFixed(1)} kg</p>
                <p>Para atingir sua meta, você precisa ${tipoMeta} <strong>${Math.abs(metaPorDia).toFixed(2)} kg/dia</strong> ao longo de <strong>${dias}</strong> dias.</p>
            </div>`;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_metas_peso_dr', 'calculator_metas_peso');

function calculator_consumo_agua() {
    echo calculator_template_start('Calculadora de Consumo Diário de Água');
    ?>
    <form id="aguaForm" style="font-family: Arial, sans-serif; max-width: 500px; margin: auto;">
        <label for="peso">Peso Corporal (kg):</label>
        <input type="number" id="peso" name="peso" step="0.1" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 70.5">

        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 25">

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select>

        <label for="nivelAtividade">Nível de Atividade Física:</label>
        <select id="nivelAtividade" name="nivelAtividade" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="sedentario">Sedentário</option>
            <option value="levementeAtivo">Levemente ativo (+10%)</option>
            <option value="moderadamenteAtivo">Moderadamente ativo (+20%)</option>
            <option value="altamenteAtivo">Altamente ativo (+30%)</option>
            <option value="extremamenteAtivo">Extremamente ativo (+40%)</option>
        </select>

        <label for="clima">Clima ou Ambiente:</label>
        <select id="clima" name="clima" style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="temperado">Temperado</option>
            <option value="quente">Quente (+10%)</option>
            <option value="seco">Seco (+10%)</option>
            <option value="frio">Frio</option>
        </select>

        <label for="estadoFisiologico">Estado Fisiológico Especial:</label>
        <select id="estadoFisiologico" name="estadoFisiologico" style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="naoAplicavel">Não aplicável</option>
            <option value="gravidez">Gravidez (+300 ml)</option>
            <option value="lactacao">Lactação (+700 ml)</option>
        </select>

        <button type="submit" style="width: 100%; background-color: #007BFF; color: white; padding: 10px; border: none; cursor: pointer;">Calcular</button>
    </form>
    
    <div id="resultado" style="margin-top: 20px; text-align: center; font-family: Arial, sans-serif;"></div>

    <script>
    document.getElementById("aguaForm").addEventListener("submit", function(event) {
        event.preventDefault();

        var peso = parseFloat(document.getElementById("peso").value);
        var idade = parseInt(document.getElementById("idade").value);
        var sexo = document.getElementById("sexo").value;
        var nivelAtividade = document.getElementById("nivelAtividade").value;
        var clima = document.getElementById("clima").value;
        var estadoFisiologico = document.getElementById("estadoFisiologico").value;

        if (isNaN(peso) || peso <= 0) {
            document.getElementById("resultado").innerHTML = "<h3 style='color: red;'>Por favor, insira um peso válido.</h3>";
            return;
        }

        if (isNaN(idade) || idade <= 0) {
            document.getElementById("resultado").innerHTML = "<h3 style='color: red;'>Por favor, insira uma idade válida.</h3>";
            return;
        }

        var consumoBasico = (peso * 35) / 1000;

        // Ajuste baseado no sexo
        if (sexo === "feminino") {
            consumoBasico *= 0.9; // Ajuste de 10% para mulheres
        }

        // Ajuste para nível de atividade
        var fatorAtividade = 1;
        switch (nivelAtividade) {
            case "levementeAtivo":
                fatorAtividade = 1.10;
                break;
            case "moderadamenteAtivo":
                fatorAtividade = 1.20;
                break;
            case "altamenteAtivo":
                fatorAtividade = 1.30;
                break;
            case "extremamenteAtivo":
                fatorAtividade = 1.40;
                break;
        }

        // Ajuste para clima
        var fatorClima = clima === "quente" || clima === "seco" ? 1.10 : 1.0;

        // Ajuste para estados fisiológicos
        var ajusteFisiologico = estadoFisiologico === "gravidez" ? 0.3 : estadoFisiologico === "lactacao" ? 0.7 : 0;

        // Cálculo total
        var consumoTotal = consumoBasico * fatorAtividade * fatorClima + ajusteFisiologico;

        document.getElementById("resultado").innerHTML = `
            <div style="border: 2px solid #007BFF; padding: 15px; border-radius: 5px; background-color: #f1f1f1;">
                <h3 style="color: #007BFF;">Consumo Diário de Água</h3>
                <p><strong>Peso:</strong> ${peso.toFixed(1)} kg</p>
                <p><strong>Idade:</strong> ${idade} anos</p>
                <p><strong>Sexo:</strong> ${sexo === "masculino" ? "Masculino" : "Feminino"}</p>
                <p><strong>Consumo Total:</strong> ${consumoTotal.toFixed(2)} litros/dia</p>
            </div>`;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_consumo_agua_dr', 'calculator_consumo_agua');

function calculator_vo2_max() {
    echo calculator_template_start('Calculadora de VO2 Máx');
    ?>
    <form id="vo2Form" style="font-family: Arial, sans-serif; max-width: 600px; margin: auto;">
        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required min="10" max="120" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 30">

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select>

        <label for="peso">Peso Corporal (kg):</label>
        <input type="number" id="peso" name="peso" step="0.1" required min="20" max="300" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 75.0">

        <label for="teste">Teste Realizado:</label>
        <select id="teste" name="teste" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="escolha">Escolha o método</option>
            <option value="cooper">Teste de Cooper (corrida de 12 min)</option>
            <option value="rockport">Teste de Rockport (caminhada de 1 milha)</option>
            <option value="bruce">Teste de Bruce (esteira)</option>
            <option value="astrand">Teste de Astrand-Ryhming (ciclismo)</option>
        </select>

        <div id="resultadosTeste"></div>

        <button type="submit" style="width: 100%; background-color: #007BFF; color: white; padding: 10px; border: none; cursor: pointer;">Calcular</button>
    </form>

    <div id="resultado" style="margin-top: 20px; text-align: center; font-family: Arial, sans-serif;"></div>

    <script>
    function renderInputsForTest(testeSelecionado) {
        var resultadosTesteDiv = document.getElementById("resultadosTeste");
        resultadosTesteDiv.innerHTML = "";

        if (testeSelecionado === "cooper") {
            resultadosTesteDiv.innerHTML = `
                <label for="distancia">Distância percorrida (metros):</label>
                <input type="number" id="distancia" name="distancia" required min="0" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 2400">
            `;
        } else if (testeSelecionado === "rockport") {
            resultadosTesteDiv.innerHTML = `
                <label for="tempo">Tempo (minutos):</label>
                <input type="number" id="tempo" name="tempo" step="0.1" required min="1" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 12.5">
                <label for="frequencia">Frequência Cardíaca Final (bpm):</label>
                <input type="number" id="frequencia" name="frequencia" required min="30" max="250" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 150">
            `;
        } else if (testeSelecionado === "bruce") {
            resultadosTesteDiv.innerHTML = `
                <label for="tempoBruce">Tempo total (minutos):</label>
                <input type="number" id="tempoBruce" name="tempoBruce" step="0.1" required min="1" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 9.5">
            `;
        } else if (testeSelecionado === "astrand") {
            resultadosTesteDiv.innerHTML = `
                <label for="frequenciaAstrand">Frequência Cardíaca Final (bpm):</label>
                <input type="number" id="frequenciaAstrand" name="frequenciaAstrand" required min="30" max="250" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 160">
                <label for="carga">Carga de Trabalho (W):</label>
                <input type="number" id="carga" name="carga" required min="10" max="500" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 100">
            `;
        }
    }

    function validarEntradas() {
        var idade = parseFloat(document.getElementById("idade").value);
        var peso = parseFloat(document.getElementById("peso").value);
        if (idade <= 0 || idade > 120) {
            alert("Por favor, insira uma idade válida (entre 10 e 120 anos). ");
            return false;
        }
        if (peso <= 0 || peso > 300) {
            alert("Por favor, insira um peso válido (entre 20 e 300 kg). ");
            return false;
        }
        return true;
    }

    document.getElementById("teste").addEventListener("change", function() {
        renderInputsForTest(this.value);
    });

    document.getElementById("vo2Form").addEventListener("submit", function(event) {
        event.preventDefault();
        if (!validarEntradas()) {
            return;
        }

        var idade = parseFloat(document.getElementById("idade").value);
        var sexo = document.getElementById("sexo").value;
        var peso = parseFloat(document.getElementById("peso").value);
        var teste = document.getElementById("teste").value;
        var vo2max = 0;

        if (teste === "cooper") {
            var distancia = parseFloat(document.getElementById("distancia").value);
            vo2max = (distancia - 504.9) / 44.73;
        } else if (teste === "rockport") {
            var tempo = parseFloat(document.getElementById("tempo").value);
            var frequencia = parseFloat(document.getElementById("frequencia").value);
            var genero = sexo === "masculino" ? 1 : 0;
            vo2max = 132.853 - (0.0769 * peso) - (0.3877 * idade) + (6.315 * genero) - (3.2649 * tempo) - (0.1565 * frequencia);
        } else if (teste === "bruce") {
            var tempoBruce = parseFloat(document.getElementById("tempoBruce").value);
            if (sexo === "masculino") {
                vo2max = 14.8 - (1.379 * tempoBruce) + (0.451 * tempoBruce * tempoBruce) - (0.012 * tempoBruce * tempoBruce * tempoBruce);
            } else {
                vo2max = 4.38 * tempoBruce - 3.9;
            }
        } else if (teste === "astrand") {
            document.getElementById("resultado").innerHTML = `<h3 style="color: red;">Cálculo baseado em tabela de Astrand. Use gráficos.</h3>`;
            return;
        }

        if (!isNaN(vo2max)) {
            document.getElementById("resultado").innerHTML = `
                <div style="border: 2px solid #007BFF; padding: 15px; border-radius: 5px; background-color: #f1f1f1;">
                    <h3 style="color: #007BFF;">VO2 Máx</h3>
                    <p>${vo2max.toFixed(2)} ml/kg/min</p>
                </div>`;
        }
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_vo2_max_dr', 'calculator_vo2_max');


function calculator_fcm() {
    echo calculator_template_start('Calculadora de Frequência Cardíaca Máxima');
    ?>
    <form id="fcmForm" style="font-family: Arial, sans-serif; max-width: 600px; margin: auto;">
        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 30">

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="" disabled selected>Selecione o sexo</option>
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select>

        <label for="formula">Fórmula:</label>
        <select id="formula" name="formula" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="classica">Fórmula Clássica (220 - Idade)</option>
            <option value="tanaka">Fórmula de Tanaka (208 - 0.7 × Idade)</option>
            <option value="gellish">Fórmula de Gellish (206.9 - 0.67 × Idade)</option>
            <option value="inbar">Fórmula de Inbar (considera o sexo)</option>
        </select>

        <button type="submit" style="width: 100%; padding: 10px; background-color: #28a745; color: white; border: none; border-radius: 4px; cursor: pointer;">
            Calcular
        </button>
    </form>

    <div id="resultado" style="margin-top: 20px; font-family: Arial, sans-serif;"></div>

    <script>
    document.getElementById("fcmForm").addEventListener("submit", function(event) {
        event.preventDefault();

        var idade = parseFloat(document.getElementById("idade").value);
        var sexo = document.getElementById("sexo").value;
        var formula = document.getElementById("formula").value;

        // Validação adicional
        if (isNaN(idade) || idade <= 0 || idade > 120) {
            alert("Por favor, insira uma idade válida entre 5 e 120 anos.");
            return;
        }

        if (!sexo) {
            alert("Por favor, selecione o sexo.");
            return;
        }

        var fcm = 0;

        // Cálculo da frequência cardíaca máxima
        if (formula === "classica") {
            fcm = 220 - idade;
        } else if (formula === "tanaka") {
            fcm = 208 - (0.7 * idade);
        } else if (formula === "gellish") {
            fcm = 206.9 - (0.67 * idade);
        } else if (formula === "inbar") {
            fcm = (sexo === "masculino") ? 205.8 - (0.685 * idade) : 206 - (0.88 * idade);
        }

        // Cálculo das zonas de treinamento
        var zonaAquecimento = [0.50 * fcm, 0.60 * fcm];
        var zonaAerobicaModerada = [0.60 * fcm, 0.70 * fcm];
        var zonaControlePeso = [0.70 * fcm, 0.80 * fcm];
        var zonaAnaerobica = [0.80 * fcm, 0.90 * fcm];
        var zonaEsforcoMaximo = [0.90 * fcm, fcm];

        // Exibição do resultado
        document.getElementById("resultado").innerHTML = `
            <h3 style="color: #333;">Frequência Cardíaca Máxima: ${fcm.toFixed(0)} bpm</h3>
            <h4>Zonas de Treinamento:</h4>
            <ul style="list-style: none; padding-left: 0; line-height: 1.6;">
                <li><strong>Zona de Aquecimento (50% - 60%):</strong> ${zonaAquecimento[0].toFixed(0)} bpm a ${zonaAquecimento[1].toFixed(0)} bpm</li>
                <li><strong>Zona Aeróbica Moderada (60% - 70%):</strong> ${zonaAerobicaModerada[0].toFixed(0)} bpm a ${zonaAerobicaModerada[1].toFixed(0)} bpm</li>
                <li><strong>Zona de Controle de Peso (70% - 80%):</strong> ${zonaControlePeso[0].toFixed(0)} bpm a ${zonaControlePeso[1].toFixed(0)} bpm</li>
                <li><strong>Zona Anaeróbica (80% - 90%):</strong> ${zonaAnaerobica[0].toFixed(0)} bpm a ${zonaAnaerobica[1].toFixed(0)} bpm</li>
                <li><strong>Zona de Esforço Máximo (90% - 100%):</strong> ${zonaEsforcoMaximo[0].toFixed(0)} bpm a ${zonaEsforcoMaximo[1].toFixed(0)} bpm</li>
            </ul>
        `;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_freq_cardiaca_maxima_dr', 'calculator_fcm');

function calculator_macronutrientes() {
    echo calculator_template_start('Calculadora de Macronutrientes');
    ?>
    <form id="macroForm" style="font-family: Arial, sans-serif; max-width: 600px; margin: auto;">
        <label for="peso">Peso (kg):</label>
        <input type="number" id="peso" name="peso" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 70">

        <label for="altura">Altura (cm):</label>
        <input type="number" id="altura" name="altura" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 170">

        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 30">

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select>

        <label for="atividade">Nível de Atividade Física:</label>
        <select id="atividade" name="atividade" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="sedentario">Sedentário</option>
            <option value="leve">Atividade Leve</option>
            <option value="moderada">Atividade Moderada</option>
            <option value="intensa">Atividade Intensa</option>
            <option value="atleta">Atleta</option>
        </select>

        <label for="objetivo">Objetivo:</label>
        <select id="objetivo" name="objetivo" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="perder_peso">Perder Peso</option>
            <option value="manter_peso">Manter Peso</option>
            <option value="ganhar_massa">Ganhar Massa Muscular</option>
        </select>

        <label for="tmb">Taxa Metabólica Basal (opcional, em kcal/dia):</label>
        <input type="number" id="tmb" name="tmb" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Deixe em branco para calcular">

        <button type="submit" style="width: 100%; background-color: #28a745; color: white; padding: 10px; border: none; cursor: pointer;">Calcular</button>
    </form>

    <div id="resultado" style="margin-top: 20px; text-align: center; font-family: Arial, sans-serif;"></div>

    <script>
    document.getElementById("macroForm").addEventListener("submit", function(event) {
        event.preventDefault();

        var peso = parseFloat(document.getElementById("peso").value);
        var altura = parseFloat(document.getElementById("altura").value);
        var idade = parseFloat(document.getElementById("idade").value);
        var sexo = document.getElementById("sexo").value;
        var atividade = document.getElementById("atividade").value;
        var objetivo = document.getElementById("objetivo").value;
        var tmbInput = parseFloat(document.getElementById("tmb").value);

        // Validações básicas
        if (peso <= 0 || altura <= 0 || idade <= 0) {
            alert("Por favor, insira valores válidos para peso, altura e idade.");
            return;
        }
        if (tmbInput && tmbInput <= 0) {
            alert("Por favor, insira um valor válido para a TMB.");
            return;
        }

        // Cálculo da TMB
        var tmb = tmbInput || (sexo === "masculino"
            ? (10 * peso) + (6.25 * altura) - (5 * idade) + 5
            : (10 * peso) + (6.25 * altura) - (5 * idade) - 161);

        // Fatores de atividade física
        var fatorAtividade = {
            "sedentario": 1.2,
            "leve": 1.375,
            "moderada": 1.55,
            "intensa": 1.725,
            "atleta": 1.9
        };

        var tdee = tmb * fatorAtividade[atividade];

        // Ajuste calórico com base no objetivo
        var ajusteCalorias = objetivo === "perder_peso" ? tdee * 0.85 :
                            objetivo === "manter_peso" ? tdee :
                            tdee * 1.10;

        // Proporção de macronutrientes
        var macros = {
            "perder_peso": { "proteinas": 0.30, "carboidratos": 0.40, "gorduras": 0.30 },
            "manter_peso": { "proteinas": 0.25, "carboidratos": 0.50, "gorduras": 0.25 },
            "ganhar_massa": { "proteinas": 0.35, "carboidratos": 0.45, "gorduras": 0.20 }
        }[objetivo];

        // Cálculo dos macronutrientes
        var gramasProteinas = ajusteCalorias * macros.proteinas / 4;
        var gramasCarboidratos = ajusteCalorias * macros.carboidratos / 4;
        var gramasGorduras = ajusteCalorias * macros.gorduras / 9;

        // Exibição dos resultados
        document.getElementById("resultado").innerHTML = `
            <div style="border: 2px solid #28a745; padding: 15px; border-radius: 5px; background-color: #f9f9f9;">
                <h3 style="color: #28a745;">Resultados</h3>
                <p><strong>Taxa Metabólica Basal (TMB):</strong> ${tmb.toFixed(2)} kcal/dia</p>
                <p><strong>Necessidade Calórica Total (TDEE):</strong> ${tdee.toFixed(2)} kcal/dia</p>
                <p><strong>Calorias Ajustadas:</strong> ${ajusteCalorias.toFixed(2)} kcal/dia</p>
                <h4>Distribuição de Macronutrientes</h4>
                <p><strong>Proteínas:</strong> ${gramasProteinas.toFixed(2)} g/dia (${(macros.proteinas * 100).toFixed(0)}% das calorias)</p>
                <p><strong>Carboidratos:</strong> ${gramasCarboidratos.toFixed(2)} g/dia (${(macros.carboidratos * 100).toFixed(0)}% das calorias)</p>
                <p><strong>Gorduras:</strong> ${gramasGorduras.toFixed(2)} g/dia (${(macros.gorduras * 100).toFixed(0)}% das calorias)</p>
            </div>`;
    });
    </script>
    <?php
    return calculator_template_end();
}

add_shortcode('calc_macronutrientes_dr', 'calculator_macronutrientes');

// revisão das calculadoras parou aqui  <<=========<<<
function calculator_percentual_gordura_corporal() {
    echo calculator_template_start('Calculadora de Percentual de Gordura Corporal');
    ?>
    <form id="gorduraForm" style="font-family: Arial, sans-serif; max-width: 600px; margin: auto;">
        <label for="peso">Peso (kg):</label>
        <input type="number" id="peso" name="peso" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 70">

        <label for="altura">Altura (cm):</label>
        <input type="number" id="altura" name="altura" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 170">

        <label for="idade">Idade (anos):</label>
        <input type="number" id="idade" name="idade" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 30">

        <label for="sexo">Sexo:</label>
        <select id="sexo" name="sexo" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select>

        <h4>Medidas Corporais</h4>
        <label for="pescoco">Circunferência do Pescoço (cm):</label>
        <input type="number" id="pescoco" name="pescoco" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 40">

        <label for="cintura">Circunferência da Cintura (cm):</label>
        <input type="number" id="cintura" name="cintura" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 80">

        <div id="quadrilField" style="display: none;">
            <label for="quadril">Circunferência do Quadril (cm):</label>
            <input type="number" id="quadril" name="quadril" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 90">
        </div>

        <label for="metodo">Método de Cálculo:</label>
        <select id="metodo" name="metodo" required style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="marinha">Fórmula da Marinha dos EUA</option>
        </select>

        <button type="submit" style="width: 100%; background-color: #007bff; color: white; padding: 10px; border: none; cursor: pointer;">Calcular</button>
    </form>

    <div id="resultado" style="margin-top: 20px; text-align: center; font-family: Arial, sans-serif;"></div>

    <script>
    document.getElementById("sexo").addEventListener("change", function() {
        var sexo = document.getElementById("sexo").value;
        document.getElementById("quadrilField").style.display = sexo === "feminino" ? "block" : "none";
    });

    document.getElementById("gorduraForm").addEventListener("submit", function(event) {
        event.preventDefault();

        // Obter valores dos inputs
        var peso = parseFloat(document.getElementById("peso").value);
        var altura = parseFloat(document.getElementById("altura").value) / 100; // Converter altura para metros
        var idade = parseFloat(document.getElementById("idade").value);
        var sexo = document.getElementById("sexo").value;
        var pescoco = parseFloat(document.getElementById("pescoco").value);
        var cintura = parseFloat(document.getElementById("cintura").value);
        var quadril = sexo === "feminino" ? parseFloat(document.getElementById("quadril").value) : 0;

        // Validar valores inseridos
        if (cintura <= pescoco) {
            alert("A circunferência da cintura deve ser maior que a do pescoço para calcular o percentual de gordura.");
            return;
        }
        if (sexo === "feminino" && (cintura + quadril - pescoco <= 0)) {
            alert("A soma de cintura + quadril menos a circunferência do pescoço deve ser positiva.");
            return;
        }

        // Cálculo do percentual de gordura corporal
        var percentualGordura = 0;
        if (sexo === "masculino") {
            percentualGordura = 86.010 * Math.log10(cintura - pescoco) - 70.041 * Math.log10(altura * 100) + 36.76;
        } else {
            percentualGordura = 163.205 * Math.log10(cintura + quadril - pescoco) - 97.684 * Math.log10(altura * 100) - 78.387;
        }

        // Validar resultado
        if (isNaN(percentualGordura) || percentualGordura < 0) {
            alert("Erro no cálculo. Verifique os valores inseridos.");
            return;
        }

        // Classificação com base no percentual de gordura
        var classificacao = sexo === "masculino"
            ? (percentualGordura < 14 ? "Atleta" : percentualGordura < 18 ? "Bom" : percentualGordura < 25 ? "Médio" : "Acima da Média")
            : (percentualGordura < 21 ? "Atleta" : percentualGordura < 25 ? "Bom" : percentualGordura < 32 ? "Médio" : "Acima da Média");

        // Exibir o resultado
        document.getElementById("resultado").innerHTML = `
            <div style="border: 2px solid #007bff; padding: 15px; border-radius: 5px; background-color: #f9f9f9;">
                <h3 style="color: #007bff;">Resultado</h3>
                <p><strong>Percentual de Gordura Corporal:</strong> ${percentualGordura.toFixed(2)}%</p>
                <p><strong>Classificação:</strong> ${classificacao}</p>
            </div>`;
    });
    </script>
    <?php
    return calculator_template_end();
}

add_shortcode('calc_percentual_gordura_dr', 'calculator_percentual_gordura_corporal');


function calculator_imc() {
    echo calculator_template_start('Calculadora de IMC');
    ?>
    <form id="imcForm" style="font-family: Arial, sans-serif; max-width: 400px; margin: auto;">
        <label for="peso">Peso (kg):</label>
        <input type="number" id="peso" name="peso" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 70">

        <label for="altura">Altura (cm):</label>
        <input type="number" id="altura" name="altura" required style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 170">

        <label for="idade">Idade (opcional):</label>
        <input type="number" id="idade" name="idade" style="width: 100%; margin-bottom: 15px; padding: 8px;" placeholder="Ex: 30">

        <label for="sexo">Sexo (opcional):</label>
        <select id="sexo" name="sexo" style="width: 100%; margin-bottom: 15px; padding: 8px;">
            <option value="">Selecione</option>
            <option value="masculino">Masculino</option>
            <option value="feminino">Feminino</option>
        </select>

        <button type="submit" style="width: 100%; background-color: #007BFF; color: white; padding: 10px; border: none; cursor: pointer;">Calcular</button>
    </form>

    <div id="resultado" style="margin-top: 20px; text-align: center; font-family: Arial, sans-serif;"></div>

    <script>
    document.getElementById("imcForm").addEventListener("submit", function(event) {
        event.preventDefault();

        var peso = parseFloat(document.getElementById("peso").value);
        var altura = parseFloat(document.getElementById("altura").value);

        if (isNaN(peso) || peso <= 0 || isNaN(altura) || altura <= 0) {
            document.getElementById("resultado").innerHTML = "<h3 style='color: red;'>Por favor, insira valores válidos para peso e altura.</h3>";
            return;
        }

        var alturaMetros = altura / 100;
        var imc = peso / (alturaMetros * alturaMetros);

        var classificacao = "";
        var corClassificacao = ""; // Para mudar a cor do resultado.

        if (imc < 18.5) {
            classificacao = "Abaixo do Peso";
            corClassificacao = "orange";
        } else if (imc >= 18.5 && imc <= 24.9) {
            classificacao = "Peso Normal";
            corClassificacao = "green";
        } else if (imc >= 25.0 && imc <= 29.9) {
            classificacao = "Sobrepeso";
            corClassificacao = "orange";
        } else if (imc >= 30.0 && imc <= 34.9) {
            classificacao = "Obesidade Grau I";
            corClassificacao = "red";
        } else if (imc >= 35.0 && imc <= 39.9) {
            classificacao = "Obesidade Grau II";
            corClassificacao = "red";
        } else {
            classificacao = "Obesidade Grau III (Obesidade Mórbida)";
            corClassificacao = "darkred";
        }

        document.getElementById("resultado").innerHTML = `
            <div style="border: 2px solid ${corClassificacao}; padding: 15px; border-radius: 5px; background-color: #f9f9f9;">
                <h3 style="color: ${corClassificacao};">Resultado:</h3>
                <p><strong>IMC:</strong> ${imc.toFixed(2)}</p>
                <p><strong>Classificação:</strong> ${classificacao}</p>
                <p>O Índice de Massa Corporal (IMC) é uma medida usada para avaliar se o peso está adequado à altura. Consulte um profissional de saúde para uma avaliação mais detalhada.</p>
            </div>`;
    });
    </script>
    <?php
    return calculator_template_end();
}
add_shortcode('calc_imc_dr', 'calculator_imc');

/*
function adicionar_frase_calculadora_no_final($content) {
    $shortcodes = array(
        'calc_vo2_max_dr', 
        'calc_reserva_vo2_dr', 
        'calc_macronutrientes_dr', 
        'calc_volume_treino_dr', 
        'calc_forca_maxima_dr', 
        'calc_consumo_agua_dr', 
        'calc_freq_cardiaca_maxima_dr', 
        'calc_imc_dr', 
        'calc_percentual_gordura_dr', 
        'calc_metas_peso_dr'
    );
    
    foreach ($shortcodes as $shortcode) {
        if (has_shortcode($content, $shortcode)) {
            // Frase a ser adicionada no final com o link
            $frase = '<p>Esta página usa uma calculadora desenvolvida por <a href="https://ambr.com.br" target="_blank">AMBR</a>.</p>';
            // Adiciona a frase ao final do conteúdo
            return $content . $frase;
        }
    }

    return $content;
}
add_filter('the_content', 'adicionar_frase_calculadora_no_final');
*/
